CREATE TABLE `actions` (
  `action` varchar(25) NOT NULL,
  `file` varchar(100) NOT NULL,
  `title` varchar(100) NOT NULL,
  `right` int(1) NOT NULL DEFAULT '0',
  `sub` varchar(25) NOT NULL DEFAULT 'main',
  `id` int(25) NOT NULL AUTO_INCREMENT,
  PRIMARY KEY (`id`),
  UNIQUE KEY `action_2` (`action`),
  KEY `action` (`action`)
) ENGINE=InnoDB AUTO_INCREMENT=1567 DEFAULT CHARSET=utf8;
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('AddFulltext','tables.pl','AddFulltext','5','AddFulltext','1');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('AnalyzeTable','tables.pl','AnalyzeTable','5','AnalyzeTable','2');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('AddPrimaryKey','tables.pl','AddPrimaryKey','5','AddPrimaryKey','3');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('ChangeEngine','tables.pl','ChangeEngine','5','ChangeEngine','4');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('ChangeAutoInCrementValue','tables.pl','ChangeAutoInCrementValue','5','ChangeAutoInCrementValue','5');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('ChangeCol','tables.pl','ChangeCol','5','ChangeCol','6');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('ChangeCharset','tables.pl','ChangeCharset','5','ChangeCharset','7');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('ChooseDataBase','tables.pl','ChooseDataBase','5','ChooseDataBase','8');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('DropTable','tables.pl','DropTable','5','DropTable','9');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('DeleteEntry','tables.pl','DeleteEntry','5','DeleteEntry','10');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('DropCol','tables.pl','DropCol','5','DropCol','11');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('ShowDumpTable','tables.pl','DumpTable','5','ShowDumpTable','12');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('ExecSql','tables.pl','ExecSql','5','ExecSql','13');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('EditTable','tables.pl','SQL','5','EditTable','14');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('EditEntry','tables.pl','EditEntry','5','EditEntry','15');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('NewEntry','tables.pl','NewEntry','5','NewEntry','16');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('NewTable','tables.pl','NewTable','5','NewTable','17');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('CreateDatabase','tables.pl','CreateDatabase','5','CreateDatabase','18');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('OptimizeTable','tables.pl','OptimizeTable','5','OptimizeTable','19');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('RepairTable','tables.pl','RepairTable','5','RepairTable','20');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('SaveEditTable','tables.pl','SaveEditTable','5','SaveEditTable','21');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('SQL','tables.pl','SQL','5','SQL','22');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('SaveEntry','tables.pl','SaveEntry','5','SaveEntry','23');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('DropFulltext','tables.pl','DropFulltext','5','DropFulltext','24');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('ShowTables','tables.pl','ShowTables','5','ShowTables','25');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('ShowTableDetails','tables.pl','ShowTableDetails','5','ShowTableDetails','26');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('ShowTable','tables.pl','ShowTable','5','ShowTable','27');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('TruncateTable','tables.pl','TruncateTable','5','TruncateTable','28');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('ShowProcesslist','tables.pl','ShowProcesslist','5','ShowProcesslist','29');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('AddIndex','tables.pl','AddIndex','5','AddIndex','30');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('DropIndex','tables.pl','DropFulltext','5','DropIndex','31');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('AddUnique','tables.pl','DropFulltext','5','AddUnique','32');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('ShowNewEntry','tables.pl','ShowNewEntry','5','ShowNewEntry','33');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('MultipleAction','tables.pl','MultipleAction','5','MultipleAction','34');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('ShowDumpDatabase','tables.pl','DumpDatabase','5','ShowDumpDatabase','35');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('SaveNewTable','tables.pl','SaveNewTable','5','SaveNewTable','36');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('EditAction','tables.pl','EditAction','5','EditAction','37');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('MultipleDbAction','tables.pl','MultipleDbAction','5','MultipleDbAction','38');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('RenameTable','tables.pl','RenameTable','5','RenameTable','39');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('SaveNewColumn','tables.pl','SaveNewColumn','5','SaveNewColumn','40');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('NewDatabase','tables.pl','NewDatabase','5','NewDatabase','41');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('ShowEditIndex','tables.pl','ShowEditIndex','5','ShowEditIndex','42');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('SaveNewIndex','tables.pl','SaveNewIndex','5','SaveNewIndex','43');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('ShowRights','tables.pl','ShowRights','5','ShowRights','44');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('SaveRights','tables.pl','SaveRights','5','SaveRights','45');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('ShowUsers','tables.pl','ShowUsers','5','ShowUsers','46');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('CreateUser','tables.pl','CreateUser','5','CreateUser','47');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('DeleteUser','tables.pl','DeleteUser','5','DeleteUser','48');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('DropDatabase','tables.pl','DropDatabase','5','DropDatabase','49');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('ShowDatabases','tables.pl','ShowDatabases','5','ShowDatabases','50');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('ShowVariables','tables.pl','ShowVariables','5','ShowVariables','51');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('searchDatabase','tables.pl','searchDatabase','5','searchDatabase','52');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('showLogin','exploit.pl','','0','main','53');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('showProfile','tables.pl','showProfile','5','showProfile','54');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('saveProfile','tables.pl','Profile','5','saveProfile','55');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('searchHelpTopic','tables.pl','Help Topic','5','searchHelpTopic','56');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('login','login.pl','Login','0','main','57');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('quickbar','quickbar.pl','quickbar','5','main','58');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('ShowNewTable','tables.pl','ShowNewTable','5','ShowNewTable','117');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('downLoadFile','tables.pl','downLoadFile','5','downLoadFile','1288');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('news','news.pl','Blog','6','show','1512');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('settings','quick.pl','Settings','5','main','1513');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('addNews','news.pl','newMessage','6','addNews','1514');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('admin','admin.pl','adminCenter','5','main','1515');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('delete','news.pl','blog','6','deleteNews','1516');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('edit','news.pl','blog','6','editNews','1517');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('saveedit','news.pl','blog','6','saveedit','1518');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('reply','news.pl','blog','6','replyNews','1519');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('profile','profile.pl','Profile','1','main','1520');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('reg','reg.pl','register','0','reg','1521');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('addReply','news.pl','blog','6','addReply','1522');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('showthread','news.pl','blog','6','showMessage','1523');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('verify','reg.pl','verify','0','verify','1524');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('fulltext','search.pl','search','0','fulltext','1525');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('newTreeviewEntry','editTree.pl','newTreeViewEntry','5','newTreeviewEntry','1526');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('saveTreeviewEntry','editTree.pl','saveTreeviewEntry','5','saveTreeviewEntry','1527');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('editTreeview','editTree.pl','editTreeview','5','editTreeview','1528');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('addTreeviewEntry','editTree.pl','addTreeviewEntry','5','addTreeviewEntry','1529');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('editTreeviewEntry','editTree.pl','editTreeviewEntry','5','editTreeviewEntry','1530');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('deleteTreeviewEntry','editTree.pl','deleteTreeviewEntry','5','deleteTreeviewEntry','1531');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('upEntry','editTree.pl','upEntry','5','upEntry','1532');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('downEntry','editTree.pl','downEntry','5','downEntry','1533');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('links','links.pl','Bookmarks','0','ShowBookmarks','1534');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('env','env.pl','env','5','main','1535');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('lostpass','login.pl','lostpass','0','lostpass','1536');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('getpass','login.pl','getpass','0','getpass','1537');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('showDir','files.pl','Files','5','showDir','1538');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('FileOpen','files.pl','FileOpen','5','FileOpen','1539');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('newFile','files.pl','newFile','5','newFile','1540');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('saveFile','files.pl','saveFile','5','saveFile','1541');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('showMessage','news.pl','blog','6','main','1542');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('chmodFile','files.pl','chmodFile','5','chmodFile','1543');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('deleteFile','files.pl','deleteFile','5','deleteFile','1544');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('makeDir','files.pl','Files','5','makeDir','1545');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('newGbookEntry','gbook.pl','gbook','6','newGbookEntry','1546');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('addnewGbookEntry','gbook.pl','gbook','6','addnewGbookEntry','1547');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('gbook','gbook.pl','gbook','6','showGbook','1548');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('deleteExploit','admin.pl','Admin','5','deleteExploit','1549');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('ImportOperaBookmarks','links.pl','ImportOperaBookmarks','5','ImportOperaBookmarks','1550');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('linkseditTreeview','editTree.pl','linkseditTreeview','5','linkseditTreeview','1551');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('EditFile','files.pl','EditAction','5','EditFile','1552');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('ExportOperaBookmarks','links.pl','ExportOperaBookmarks','0','ExportOperaBookmarks','1553');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('MoveTreeViewEntry','editTree.pl','MoveTreeViewEntry','5','MoveTreeViewEntry','1554');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('chownFile','files.pl','chownFile','5','chownFile','1556');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('ImportFireFoxBookmarks','links.pl','ImportFireFoxBookmarks','5','ImportFireFoxBookmarks','1557');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('rebuildtrash','news.pl','weblog','6','rebuildtrash','1558');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('trash','news.pl','trash','6','trash','1559');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('showaddTranslation','addtranslate.pl','showaddTranslation','5','main','1560');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('translate','translate.pl','translate','5','main','1561');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('deleteTreeviewEntrys','editTree.pl','Edit','5','deleteTreeviewEntrys','1562');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('makeUser','reg.pl','register','0','make','1565');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('navigation','navigation.pl','navigation','0','main','1566');

CREATE TABLE `actions_set` (
  `action` varchar(25) NOT NULL,
  `foreign_action` varchar(25) NOT NULL,
  `output_id` varchar(25) NOT NULL DEFAULT '25',
  `id` int(25) NOT NULL AUTO_INCREMENT,
  PRIMARY KEY (`id`),
  KEY `foreign_action` (`foreign_action`),
  CONSTRAINT `actions_set_ibfk_1` FOREIGN KEY (`foreign_action`) REFERENCES `actions` (`action`) ON DELETE CASCADE ON UPDATE CASCADE
) ENGINE=InnoDB AUTO_INCREMENT=415 DEFAULT CHARSET=utf8;
INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('AddFulltext','AddFulltext','content','1');
INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('AnalyzeTable','AnalyzeTable','content','2');
INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('AddPrimaryKey','AddPrimaryKey','content','3');
INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('ChangeEngine','ChangeEngine','content','4');
INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('ChangeAutoInCrementValue','ChangeAutoInCrementValue','content','5');
INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('ChangeCol','ChangeCol','content','6');
INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('ChangeCharset','ChangeCharset','content','7');
INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('ChooseDataBase','ChooseDataBase','content','8');
INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('DropTable','DropTable','content','9');
INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('DeleteEntry','DeleteEntry','content','10');
INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('DropCol','DropCol','content','11');
INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('ShowDumpTable','ShowDumpTable','content','12');
INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('ExecSql','ExecSql','content','13');
INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('EditTable','EditTable','content','14');
INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('EditEntry','EditEntry','content','15');
INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('NewEntry','NewEntry','content','16');
INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('NewTable','NewTable','content','17');
INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('CreateDatabase','CreateDatabase','content','18');
INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('OptimizeTable','OptimizeTable','content','19');
INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('RepairTable','RepairTable','content','20');
INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('SaveEditTable','SaveEditTable','content','21');
INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('SQL','SQL','content','22');
INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('SaveEntry','SaveEntry','content','23');
INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('DropFulltext','DropFulltext','content','24');
INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('ShowTables','ShowTables','content','25');
INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('ShowTableDetails','ShowTableDetails','content','26');
INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('ShowTable','ShowTable','content','27');
INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('TruncateTable','TruncateTable','content','28');
INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('ShowProcesslist','ShowProcesslist','content','29');
INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('AddIndex','AddIndex','content','30');
INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('DropIndex','DropFulltext','content','31');
INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('AddUnique','AddUnique','content','32');
INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('ShowNewEntry','ShowNewEntry','content','33');
INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('MultipleAction','MultipleAction','content','34');
INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('ShowDumpDatabase','ShowDumpDatabase','content','35');
INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('SaveNewTable','SaveNewTable','content','36');
INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('EditAction','EditAction','content','37');
INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('MultipleDbAction','MultipleDbAction','content','38');
INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('RenameTable','RenameTable','content','39');
INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('SaveNewColumn','SaveNewColumn','content','40');
INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('NewDatabase','NewDatabase','content','41');
INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('ShowEditIndex','ShowEditIndex','content','42');
INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('SaveNewIndex','SaveNewIndex','content','43');
INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('ShowRights','ShowRights','content','44');
INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('SaveRights','SaveRights','content','45');
INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('ShowUsers','ShowUsers','content','46');
INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('CreateUser','CreateUser','content','47');
INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('DeleteUser','DeleteUser','content','48');
INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('DropDatabase','DropDatabase','content','49');
INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('ShowDatabases','ShowDatabases','content','50');
INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('ShowVariables','ShowVariables','content','51');
INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('searchDatabase','searchDatabase','content','52');
INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('showLogin','showLogin','content','53');
INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('showProfile','showProfile','content','54');
INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('searchHelpTopic','searchHelpTopic','content','56');
INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('ShowNewTable','ShowNewTable','content','57');
INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('downLoadFile','downLoadFile','content','138');
INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('news','news','content','139');
INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('settings','settings','content','140');
INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('addNews','addNews','content','141');
INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('admin','admin','content','142');
INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('delete','delete','content','143');
INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('edit','edit','content','144');
INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('saveedit','saveedit','content','145');
INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('reply','reply','content','146');
INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('profile','profile','content','147');
INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('reg','reg','content','148');
INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('addReply','addReply','content','149');
INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('showthread','showthread','content','150');
INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('verify','verify','content','152');
INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('fulltext','fulltext','content','153');
INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('newTreeviewEntry','newTreeviewEntry','content','154');
INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('saveTreeviewEntry','saveTreeviewEntry','content','155');
INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('editTreeview','editTreeview','content','156');
INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('addTreeviewEntry','addTreeviewEntry','content','157');
INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('editTreeviewEntry','editTreeviewEntry','content','158');
INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('deleteTreeviewEntry','deleteTreeviewEntry','content','159');
INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('upEntry','upEntry','content','160');
INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('downEntry','downEntry','content','161');
INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('links','links','content','162');
INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('env','env','content','163');
INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('lostpass','lostpass','content','164');
INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('getpass','getpass','content','165');
INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('showDir','showDir','content','166');
INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('FileOpen','FileOpen','content','167');
INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('newFile','newFile','content','168');
INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('saveFile','saveFile','content','169');
INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('showMessage','showMessage','content','170');
INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('chmodFile','chmodFile','content','171');
INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('deleteFile','deleteFile','content','172');
INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('makeDir','makeDir','content','173');
INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('newGbookEntry','newGbookEntry','content','174');
INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('addnewGbookEntry','addnewGbookEntry','content','175');
INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('gbook','gbook','content','176');
INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('deleteExploit','deleteExploit','content','177');
INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('ImportOperaBookmarks','ImportOperaBookmarks','content','179');
INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('linkseditTreeview','linkseditTreeview','content','180');
INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('EditFile','EditFile','content','181');
INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('ExportOperaBookmarks','ExportOperaBookmarks','content','182');
INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('MoveTreeViewEntry','MoveTreeViewEntry','content','183');
INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('chownFile','chownFile','content','184');
INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('ImportFireFoxBookmarks','ImportFireFoxBookmarks','content','185');
INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('rebuildtrash','rebuildtrash','content','186');
INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('trash','trash','content','187');
INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('showaddTranslation','showaddTranslation','content','188');
INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('translate','translate','content','189');
INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('deleteTreeviewEntrys','deleteTreeviewEntrys','content','190');
INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('makeUser','makeUser','content','244');
INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('default','navigation','treeview','412');
INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('default','login','login','413');
INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('showDatabases','quickbar','quickbar','414');

CREATE TABLE `cats` (
  `name` varchar(100) NOT NULL DEFAULT '',
  `right` int(11) NOT NULL DEFAULT '0',
  `id` int(11) NOT NULL AUTO_INCREMENT,
  PRIMARY KEY (`id`)
) ENGINE=MyISAM AUTO_INCREMENT=6 DEFAULT CHARSET=utf8;
INSERT INTO `cats` (`name`,`right`,`id`) values('news','0','1');
INSERT INTO `cats` (`name`,`right`,`id`) values('member','1','2');
INSERT INTO `cats` (`name`,`right`,`id`) values('draft','2','5');

CREATE TABLE `exploit` (
  `date` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  `referer` text NOT NULL,
  `remote_addr` text NOT NULL,
  `query_string` text NOT NULL,
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `count` int(11) NOT NULL,
  PRIMARY KEY (`id`),
  UNIQUE KEY `id` (`id`),
  FULLTEXT KEY `remote_addr` (`remote_addr`)
) ENGINE=MyISAM AUTO_INCREMENT=16 DEFAULT CHARSET=utf8;

CREATE TABLE `flood` (
  `remote_addr` text NOT NULL,
  `ti` text NOT NULL,
  `id` int(11) NOT NULL AUTO_INCREMENT,
  PRIMARY KEY (`id`)
) ENGINE=MyISAM AUTO_INCREMENT=2 DEFAULT CHARSET=utf8;

CREATE TABLE `gbook` (
  `title` varchar(50) NOT NULL DEFAULT '',
  `body` text NOT NULL,
  `date` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  `user` text NOT NULL,
  `id` int(11) NOT NULL AUTO_INCREMENT,
  PRIMARY KEY (`id`),
  FULLTEXT KEY `title` (`title`,`body`)
) ENGINE=MyISAM AUTO_INCREMENT=3 DEFAULT CHARSET=utf8;
INSERT INTO `gbook` (`title`,`body`,`date`,`user`,`id`) values('Überschrift','Erstelle Deine Nachricht.','2015-09-22 07:47:36','admin','1');
INSERT INTO `gbook` (`title`,`body`,`date`,`user`,`id`) values('Überschrift','Erstelle Deine Nachricht. ä#+üö','2015-09-22 19:41:09','admin','2');

CREATE TABLE `navigation` (
  `title` varchar(100) NOT NULL DEFAULT '',
  `action` varchar(100) NOT NULL DEFAULT '',
  `src` varchar(100) NOT NULL DEFAULT '',
  `right` int(11) NOT NULL DEFAULT '0',
  `position` int(5) DEFAULT NULL,
  `submenu` varchar(100) DEFAULT NULL,
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `target` int(11) DEFAULT NULL,
  PRIMARY KEY (`id`)
) ENGINE=MyISAM AUTO_INCREMENT=9 DEFAULT CHARSET=utf8;
INSERT INTO `navigation` (`title`,`action`,`src`,`right`,`position`,`submenu`,`id`,`target`) values('blog','news','news.png','6','1','','1','0');
INSERT INTO `navigation` (`title`,`action`,`src`,`right`,`position`,`submenu`,`id`,`target`) values('Admin','admin','admin.png','5','3','submenuadmin','2','0');
INSERT INTO `navigation` (`title`,`action`,`src`,`right`,`position`,`submenu`,`id`,`target`) values('properties','profile','profile.png','1','5','','3','0');
INSERT INTO `navigation` (`title`,`action`,`src`,`right`,`position`,`submenu`,`id`,`target`) values('links','links','link.png','0','4','','5','0');
INSERT INTO `navigation` (`title`,`action`,`src`,`right`,`position`,`submenu`,`id`,`target`) values('gbook','gbook','link.png','6','8','','7','0');
INSERT INTO `navigation` (`title`,`action`,`src`,`right`,`position`,`submenu`,`id`,`target`) values('ShowDatabases','ShowDatabases','link.png','5','2','submenu_database','8','0');

CREATE TABLE `news` (
  `title` varchar(100) NOT NULL DEFAULT '',
  `body` text NOT NULL,
  `date` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  `user` text NOT NULL,
  `right` int(11) NOT NULL DEFAULT '0',
  `attach` varchar(100) NOT NULL DEFAULT '0',
  `cat` varchar(25) NOT NULL DEFAULT 'news',
  `action` varchar(50) NOT NULL DEFAULT 'main',
  `sticky` int(1) NOT NULL DEFAULT '0',
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `format` varchar(10) NOT NULL DEFAULT 'bbcode',
  PRIMARY KEY (`id`),
  FULLTEXT KEY `title` (`title`,`body`)
) ENGINE=MyISAM AUTO_INCREMENT=24 DEFAULT CHARSET=utf8;
INSERT INTO `news` (`title`,`body`,`date`,`user`,`right`,`attach`,`cat`,`action`,`sticky`,`id`,`format`) values('Überschrift','Erstelle Deine Nachricht#äü','2015-10-03 11:35:40','admin','0','0','news','news','0','22','bbcode');
INSERT INTO `news` (`title`,`body`,`date`,`user`,`right`,`attach`,`cat`,`action`,`sticky`,`id`,`format`) values('Überschrift','Erstelle Deine Nachrichtddgfg','2015-10-07 18:34:36','admin','0','0','news','news','0','23','bbcode');
INSERT INTO `news` (`title`,`body`,`date`,`user`,`right`,`attach`,`cat`,`action`,`sticky`,`id`,`format`) values('Überschrift','Erstelle Deine Nachricht','2015-09-29 15:13:18','admin','0','0','news','news','0','18','bbcode');

CREATE TABLE `querys` (
  `title` varchar(100) NOT NULL DEFAULT '',
  `description` text NOT NULL,
  `sql` text NOT NULL,
  `return` varchar(100) NOT NULL DEFAULT 'fetch_array',
  `id` int(11) NOT NULL AUTO_INCREMENT,
  PRIMARY KEY (`id`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

CREATE TABLE `replies` (
  `title` varchar(100) NOT NULL,
  `body` text NOT NULL,
  `date` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  `user` text NOT NULL,
  `right` int(10) NOT NULL DEFAULT '0',
  `attach` varchar(100) NOT NULL DEFAULT '0',
  `refererId` varchar(50) NOT NULL,
  `sticky` int(1) NOT NULL DEFAULT '0',
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `format` varchar(10) NOT NULL DEFAULT 'bbcode',
  `cat` varchar(25) NOT NULL DEFAULT 'replies',
  PRIMARY KEY (`id`),
  FULLTEXT KEY `title` (`title`,`body`)
) ENGINE=MyISAM AUTO_INCREMENT=9 DEFAULT CHARSET=utf8;
INSERT INTO `replies` (`title`,`body`,`date`,`user`,`right`,`attach`,`refererId`,`sticky`,`id`,`format`,`cat`) values('headline','inserttextas','2015-08-06 09:21:11','admin','0','0','25','0','1','bbcode','replies');
INSERT INTO `replies` (`title`,`body`,`date`,`user`,`right`,`attach`,`refererId`,`sticky`,`id`,`format`,`cat`) values('Überschrift','inserttext','2015-08-07 14:56:01','guest','0','0','25','0','3','bbcode','replies');
INSERT INTO `replies` (`title`,`body`,`date`,`user`,`right`,`attach`,`refererId`,`sticky`,`id`,`format`,`cat`) values('uberschrift','Text einfügen','2015-08-08 07:23:47','admin','0','0','4','0','4','bbcode','replies');
INSERT INTO `replies` (`title`,`body`,`date`,`user`,`right`,`attach`,`refererId`,`sticky`,`id`,`format`,`cat`) values('Überschrift','Text einfügen #ö+#ü+äö','2015-09-22 19:03:00','admin','0','0','14','0','5','bbcode','');
INSERT INTO `replies` (`title`,`body`,`date`,`user`,`right`,`attach`,`refererId`,`sticky`,`id`,`format`,`cat`) values('Überschrift','Text einfügen','2015-10-07 18:34:13','admin','0','0','22','0','6','bbcode','replies');
INSERT INTO `replies` (`title`,`body`,`date`,`user`,`right`,`attach`,`refererId`,`sticky`,`id`,`format`,`cat`) values('Überschrift','Text einfügendfgdfg','2015-10-07 18:34:43','admin','0','0','22','0','7','bbcode','replies');
INSERT INTO `replies` (`title`,`body`,`date`,`user`,`right`,`attach`,`refererId`,`sticky`,`id`,`format`,`cat`) values('Überschrift','Text einfügendgdfgdfgd','2015-10-07 18:34:55','admin','0','0','22','0','8','bbcode','replies');

CREATE TABLE `reserved_words` (
  `reserved_word` varchar(50) DEFAULT NULL,
  `id` int(11) NOT NULL AUTO_INCREMENT,
  PRIMARY KEY (`id`)
) ENGINE=MyISAM AUTO_INCREMENT=224 DEFAULT CHARSET=latin1;
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('ACCESSIBLE','1');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('ALTER','2');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('AS','3');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('BEFORE','4');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('BINARY','5');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('BY','6');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('CASE','7');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('CHARACTER','8');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('COLUMN','9');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('CONTINUE','10');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('CROSS','11');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('CURRENT_TIMESTAMP','12');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('DATABASE','13');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('DAY_MICROSECOND','14');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('DEC','15');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('DEFAULT','16');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('DESC','17');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('DISTINCT','18');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('DOUBLE','19');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('EACH','20');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('ENCLOSED','21');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('EXIT','22');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('FETCH','23');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('FLOAT8','24');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('FOREIGN','25');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('GRANT','26');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('HIGH_PRIORITY','27');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('HOUR_SECOND','28');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('IN','29');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('INNER','30');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('INSERT','31');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('INT2','32');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('INT8','33');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('INTO','34');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('JOIN','35');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('KILL','36');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('LEFT','37');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('LINEAR','38');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('LOCALTIME','39');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('LONG','40');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('LOOP','41');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('MATCH','42');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('MEDIUMTEXT','43');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('MINUTE_SECOND','44');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('NATURAL','45');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('NULL','46');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('OPTIMIZE','47');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('OR','48');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('OUTER','49');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('PRIMARY','50');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('RANGE','51');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('READ_WRITE','52');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('REGEXP','53');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('REPEAT','54');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('RESTRICT','55');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('RIGHT','56');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('SCHEMAS','57');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('SENSITIVE','58');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('SHOW','59');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('SPECIFIC','60');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('SQLSTATE','61');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('SQL_CALC_FOUND_ROWS','62');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('STARTING','63');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('TERMINATED','64');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('TINYINT','65');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('TRAILING','66');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('UNDO','67');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('UNLOCK','68');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('USAGE','69');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('UTC_DATE','70');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('VALUES','71');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('VARCHARACTER','72');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('WHERE','73');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('WRITE','74');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('ZEROFILL','75');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('ALL','76');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('AND','77');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('ASENSITIVE','78');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('BIGINT','79');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('BOTH','80');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('CASCADE','81');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('CHAR','82');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('COLLATE','83');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('CONSTRAINT','84');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('CREATE','85');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('CURRENT_TIME','86');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('CURSOR','87');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('DAY_HOUR','88');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('DAY_SECOND','89');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('DECLARE','90');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('DELETE','91');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('DETERMINISTIC','92');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('DIV','93');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('DUAL','94');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('ELSEIF','95');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('EXISTS','96');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('FALSE','97');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('FLOAT4','98');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('FORCE','99');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('FULLTEXT','100');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('HAVING','101');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('HOUR_MINUTE','102');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('IGNORE','103');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('INFILE','104');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('INSENSITIVE','105');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('INT1','106');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('INT4','107');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('INTERVAL','108');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('ITERATE','109');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('KEYS','110');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('LEAVE','111');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('LIMIT','112');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('LOAD','113');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('LOCK','114');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('LONGTEXT','115');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('MASTER_SSL_VERIFY_SERVER_CERT','116');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('MEDIUMINT','117');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('MINUTE_MICROSECOND','118');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('MODIFIES','119');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('NO_WRITE_TO_BINLOG','120');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('ON','121');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('OPTIONALLY','122');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('OUT','123');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('PRECISION','124');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('PURGE','125');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('READS','126');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('REFERENCES','127');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('RENAME','128');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('REQUIRE','129');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('REVOKE','130');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('SCHEMA','131');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('SELECT','132');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('SET','133');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('SPATIAL','134');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('SQLEXCEPTION','135');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('SQL_BIG_RESULT','136');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('SSL','137');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('TABLE','138');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('TINYBLOB','139');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('TO','140');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('TRUE','141');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('UNIQUE','142');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('UPDATE','143');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('USING','144');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('UTC_TIMESTAMP','145');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('VARCHAR','146');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('WHEN','147');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('WITH','148');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('YEAR_MONTH','149');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('ADD','150');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('ANALYZE','151');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('ASC','152');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('BETWEEN','153');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('BLOB','154');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('CALL','155');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('CHANGE','156');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('CHECK','157');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('CONDITION','158');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('CONVERT','159');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('CURRENT_DATE','160');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('CURRENT_USER','161');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('DATABASES','162');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('DAY_MINUTE','163');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('DECIMAL','164');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('DELAYED','165');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('DESCRIBE','166');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('DISTINCTROW','167');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('DROP','168');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('ELSE','169');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('ESCAPED','170');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('EXPLAIN','171');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('FLOAT','172');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('FOR','173');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('FROM','174');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('GROUP','175');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('HOUR_MICROSECOND','176');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('IF','177');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('INDEX','178');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('INOUT','179');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('INT','180');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('INT3','181');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('INTEGER','182');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('IS','183');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('KEY','184');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('LEADING','185');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('LIKE','186');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('LINES','187');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('LOCALTIMESTAMP','188');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('LONGBLOB','189');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('LOW_PRIORITY','190');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('MEDIUMBLOB','191');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('MIDDLEINT','192');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('MOD','193');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('NOT','194');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('NUMERIC','195');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('OPTION','196');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('ORDER','197');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('OUTFILE','198');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('PROCEDURE','199');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('READ','200');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('REAL','201');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('RELEASE','202');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('REPLACE','203');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('RETURN','204');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('RLIKE','205');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('SECOND_MICROSECOND','206');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('SEPARATOR','207');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('SMALLINT','208');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('SQL','209');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('SQLWARNING','210');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('SQL_SMALL_RESULT','211');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('STRAIGHT_JOIN','212');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('THEN','213');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('TINYTEXT','214');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('TRIGGER','215');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('UNION','216');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('UNSIGNED','217');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('USE','218');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('UTC_TIME','219');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('VARBINARY','220');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('VARYING','221');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('WHILE','222');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('XOR','223');

CREATE TABLE `submenu_database` (
  `title` varchar(100) NOT NULL DEFAULT '',
  `action` varchar(100) NOT NULL DEFAULT '',
  `src` varchar(100) NOT NULL DEFAULT 'link.gif',
  `right` int(11) NOT NULL DEFAULT '0',
  `submenu` varchar(100) DEFAULT NULL,
  `id` int(11) NOT NULL AUTO_INCREMENT,
  PRIMARY KEY (`id`)
) ENGINE=MyISAM AUTO_INCREMENT=24 DEFAULT CHARSET=utf8;
INSERT INTO `submenu_database` (`title`,`action`,`src`,`right`,`submenu`,`id`) values('ShowProcesslist','ShowProcesslist','','5','','5');
INSERT INTO `submenu_database` (`title`,`action`,`src`,`right`,`submenu`,`id`) values('ShowVariables','ShowVariables','','5','','6');
INSERT INTO `submenu_database` (`title`,`action`,`src`,`right`,`submenu`,`id`) values('ShowDumpDatabase','ShowDumpDatabase','','5','','4');
INSERT INTO `submenu_database` (`title`,`action`,`src`,`right`,`submenu`,`id`) values('ShowTables','showTables','','5','','2');
INSERT INTO `submenu_database` (`title`,`action`,`src`,`right`,`submenu`,`id`) values('ShowUsers','ShowUsers','','5','','3');

CREATE TABLE `submenuadmin` (
  `title` varchar(100) NOT NULL DEFAULT '',
  `action` varchar(100) NOT NULL DEFAULT '',
  `src` varchar(100) NOT NULL DEFAULT 'link.gif',
  `right` int(11) NOT NULL DEFAULT '0',
  `submenu` varchar(100) DEFAULT NULL,
  `id` int(11) NOT NULL AUTO_INCREMENT,
  PRIMARY KEY (`id`)
) ENGINE=MyISAM AUTO_INCREMENT=18 DEFAULT CHARSET=utf8;
INSERT INTO `submenuadmin` (`title`,`action`,`src`,`right`,`submenu`,`id`) values('settings','settings','link.gif','5','','2');
INSERT INTO `submenuadmin` (`title`,`action`,`src`,`right`,`submenu`,`id`) values('navigation','editTreeview','','5','','4');
INSERT INTO `submenuadmin` (`title`,`action`,`src`,`right`,`submenu`,`id`) values('env','env','link.gif','5','','6');
INSERT INTO `submenuadmin` (`title`,`action`,`src`,`right`,`submenu`,`id`) values('Editlinks','linkseditTreeview','link.gif','5','','5');
INSERT INTO `submenuadmin` (`title`,`action`,`src`,`right`,`submenu`,`id`) values('Explorer','showDir','link.gif','5','','1');
INSERT INTO `submenuadmin` (`title`,`action`,`src`,`right`,`submenu`,`id`) values('trash','trash','','6','','7');
INSERT INTO `submenuadmin` (`title`,`action`,`src`,`right`,`submenu`,`id`) values('translate','translate','link.png','5','','3');

CREATE TABLE `trash` (
  `table` varchar(50) NOT NULL DEFAULT '',
  `oldId` bigint(50) NOT NULL DEFAULT '0',
  `title` varchar(100) NOT NULL DEFAULT '',
  `body` text NOT NULL,
  `date` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  `user` text NOT NULL,
  `right` int(11) NOT NULL DEFAULT '0',
  `attach` varchar(100) NOT NULL DEFAULT '0',
  `cat` varchar(25) NOT NULL DEFAULT 'main',
  `action` varchar(50) NOT NULL DEFAULT 'news',
  `sticky` int(1) NOT NULL DEFAULT '0',
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `format` varchar(10) NOT NULL DEFAULT 'bbcode',
  `refererId` int(11) NOT NULL,
  PRIMARY KEY (`id`),
  FULLTEXT KEY `title` (`title`,`body`)
) ENGINE=MyISAM AUTO_INCREMENT=8 DEFAULT CHARSET=utf8;

CREATE TABLE `users` (
  `pass` text NOT NULL,
  `user` varchar(25) NOT NULL DEFAULT '',
  `date` date NOT NULL DEFAULT '0000-00-00',
  `email` varchar(100) NOT NULL DEFAULT '',
  `right` int(11) NOT NULL DEFAULT '0',
  `name` varchar(100) NOT NULL DEFAULT '',
  `firstname` varchar(100) NOT NULL DEFAULT '',
  `street` varchar(100) DEFAULT NULL,
  `city` varchar(100) DEFAULT NULL,
  `postcode` varchar(20) DEFAULT NULL,
  `phone` varchar(50) DEFAULT NULL,
  `sid` varchar(200) DEFAULT NULL,
  `ip` varchar(50) DEFAULT NULL,
  `cats` text,
  `id` int(11) NOT NULL AUTO_INCREMENT,
  PRIMARY KEY (`id`)
) ENGINE=MyISAM AUTO_INCREMENT=3 DEFAULT CHARSET=utf8;
INSERT INTO `users` (`pass`,`user`,`date`,`email`,`right`,`name`,`firstname`,`street`,`city`,`postcode`,`phone`,`sid`,`ip`,`cats`,`id`) values('guest','guest','0000-00-00','','0','','',NULL,NULL,NULL,NULL,'123','dd','news','1');

