$VAR1 = {
          'en' => {
                    'VARBINARY' => '0-65,535 bytesM=0-255 v5.0.3 Attributes: Global Only(case sensitive) Default: NULL ["" if NOT NULL]',
                    'news_pro_page' => 'news_pro_page',
                    'YEAR' => '1900 - 2155 Attributes: Global Only(YYYY) Default: NULL["0000" if NOT NULL]',
                    'documentroot' => 'documentroot',
                    'analyzetable' => 'Analyze Table',
                    'right_username_text' => 'Ok',
                    'DropTable' => 'Tables',
                    'ShowTableDetails' => 'Details',
                    'sub_part' => 'sub_part',
                    'showeditindex' => 'New Index',
                    'choosefile' => 'choosefile',
                    'uploadsize' => 'uploadsize',
                    'failedinvalidcode' => 'Failed invalid code',
                    'MEDIUMBLOB' => '0-16,777,215 bytes Attributes: Global Only(case sensitive) Default: NULL ["" if NOT NULL]',
                    'BIGINT' => '-/+9.223E+18 [0 to 18.45E+18] Attributes: AUTO_INCREMENT, UNSIGNED, ZEROFILL,SERIAL DEFAULT VALUE Default: NULL [0 if NOT NULL]',
                    'retry' => 'retry',
                    'exportdatabase' => 'Database',
                    'edittableprops' => 'Table',
                    'AddIndex' => 'Index hinzufügen',
                    'select_all' => 'Select All',
                    'host' => 'Host',
                    'done' => 'done',
                    'userprofile' => 'userprofile',
                    'rowsineffect' => 'rows in effect',
                    'SaveEditTable' => 'Table',
                    'endtable' => 'at end',
                    'TIME' => '"-838:59:59" - "838:59:59" Attributes: Global Only(hh:mm:ss) Default: NULL["00:00:00" if NOT NULL]',
                    'savetranslate' => 'savetranslate',
                    'showProfile' => 'Profile',
                    'USER_CONNECTIONS' => 'Max User',
                    'preview' => 'preview',
                    'field' => 'field',
                    'size' => 'Size',
                    'createtable' => 'New Table',
                    'MEDIUMTEXT' => '0-16,777,215 Chars Attributes: BINARY, CHARACTER SET Default: NULL ["" if NOT NULL]',
                    'over' => 'over',
                    'right_passwort_text' => 'Ok',
                    'drop_database' => 'Drop Database',
                    'Create' => 'Create',
                    'showsqlsearch' => 'Search in DB',
                    'editentry' => 'Edit Entry',
                    'homepagetitle' => 'homepagetitle',
                    'reply' => 'reply',
                    'next' => 'Next',
                    'shownewrow' => 'New Row',
                    'Extra' => 'Extra',
                    'AddPrimaryKey' => 'AddPrimaryKey',
                    'sharelink' => 'sharelink',
                    'uploadchmod' => 'uploadchmod',
                    'activates' => 'activates',
                    'permalink' => 'permalink',
                    'city' => 'city',
                    'edittranslation' => 'edittranslation',
                    'DECIMAL' => 'Stored as string Max Range = DOUBLE rangeFixed point vs. DOUBLE float Attributes: UNSIGNED, ZEROFILL Default: NULL [0 if NOT NULL]',
                    'maxlength' => 'maxlength',
                    'SET' => '("A1","A2",...) Column is 0 or more values in list of 1-64 members Attributes: CHARACTER SET Default: NULL ["" if NOT NULL]',
                    'explorer' => 'explorer',
                    'gbook' => 'gbook',
                    'delete' => 'Delete',
                    'shownewentry' => 'New Entry',
                    'regexp' => 'Regular Expression',
                    'unselect_all' => 'Unselect',
                    'showtables' => 'Tables',
                    'createindex' => 'New Index',
                    'starttable' => 'at start',
                    'login' => 'Login',
                    'column_name' => 'column_name',
                    'rebuild' => 'rebuild',
                    'showdatabases' => 'Databases',
                    'welcome' => 'Welcome',
                    'DATE' => '"1000-01-01" - "9999-12-31" Attributes: Global Only(YYYY-MM-DD) Default: NULL["0000-00-00" if NOT NULL]',
                    'right_database_name' => 'right_database_name',
                    'trash' => 'trash',
                    'searchDatabase' => 'Search',
                    'email' => 'email',
                    'details' => 'Details',
                    'sql' => 'SQL',
                    'timebetweenposts' => 'timebetweenposts',
                    'change' => 'Ändern',
                    'TINYBLOB' => '0-255 bytes Attributes: Global Only(case sensitive) Default: NULL ["" if NOT NULL]',
                    'mailsubject' => 'mailsubject',
                    'SaveRights' => 'Rights',
                    'changeautoincrementvalue' => 'Auto Increment Value',
                    'env' => 'env',
                    'showsqleditor' => 'Sql',
                    'FLOAT' => 'Min=+/-1.175E-38 Max=+/-3.403E+38 Attributes: UNSIGNED, ZEROFILL Default: NULL [0 if NOT NULL]',
                    'processlist' => 'Processes',
                    'RenameTable' => 'rename Table',
                    'save' => 'Save',
                    'settings' => 'settings',
                    'firstname' => 'firstname',
                    'editnavi' => 'editnavi',
                    'editlinks' => 'editlinks',
                    'regmessage' => 'regmessage',
                    'AddFulltext' => 'Add Fulltext',
                    'downLoadFile' => 'Download',
                    'defaultaction' => 'defaultaction',
                    'uploadpath' => 'uploadpath',
                    'showcreateuser' => 'New User',
                    'collation' => 'Collation',
                    'wrong_database_name' => 'wrong_database_name',
                    'catslist' => 'catslist',
                    'DropColumn' => 'Drop Column',
                    'execsql' => 'Sql',
                    'TIMESTAMP' => '19700101000000 -2037+ Attributes: Global Only(YYYYMMDDhhmmss) Default: Current Date &amp; Time',
                    'createdatabase' => 'New Database',
                    'key_name' => 'key_name',
                    'sqlsearch' => 'Search',
                    'user' => 'Username',
                    'rights' => 'rights',
                    'showtable' => 'Table',
                    'showusers' => 'User',
                    'seq_in_index' => 'seq_in_index',
                    'after' => 'after',
                    'search' => 'Search',
                    'TINYINT' => 'TINYINT -128 TO 127  [0 to 255 if UNSIGNED],Attributes: AUTO_INCREMENT  UNSIGNED, ZEROFILL,SERIAL DEFAULT VALUE Default: NULL [0 if NOT NULL]',
                    'optimize' => 'Optimize',
                    'database' => 'Database',
                    'VARCHAR' => 'M=0-65,535 CharactersM=0-255 v5.0.3 Attributes: BINARY, CHARACTER SET Default: NULL ["" if NOT NULL]',
                    'AddUnique' => 'Unique Index hinzufügen',
                    'password' => 'Password',
                    'Default' => 'Default',
                    'BINARY' => 'M=0-255 bytes, FIXED. Attributes: Global Only(case sensitive) Default: NULL ["" if NOT NULL]',
                    'showchangecurrentdb' => 'Server',
                    'links_pro_page' => 'Links/Page',
                    'non_unique' => 'non_unique',
                    'body' => 'body',
                    'links' => 'links',
                    'exportoperabookmarks' => 'exportoperabookmarks',
                    'ShowNewTable' => 'Database',
                    'reg' => 'Register',
                    'insert' => 'Insert',
                    'wrong_username_text' => 'The Username must be at least 3 characters in length and can only contain letters or digits.',
                    'blog' => 'blog',
                    'newpass' => 'New Password',
                    'importoperabookmarks' => 'importoperabookmarks',
                    'connect' => 'Connect',
                    'register' => 'Register',
                    'nomail' => 'nomail',
                    'create' => 'Create',
                    'wrong_captcha_text' => 'wrong_captcha_text',
                    't_regtext' => 't_regtext',
                    'BLOB' => '0-65,535 bytes Attributes: Global Only(case sensitive) Default: NULL ["" if NOT NULL]',
                    'answers' => 'answers',
                    'comment' => 'Comment',
                    'showdumptable' => 'Export',
                    'back' => 'back',
                    'gbook_body' => 'gbook_body',
                    'changecharset' => 'Change Charset',
                    'indexover' => 'Index over',
                    'newmessage' => 'newmessage',
                    'type' => 'Type',
                    'htmlright' => 'htmlright',
                    'Attribute' => 'Attribute',
                    'showdumpdatabase' => 'Export',
                    'packed' => 'packed',
                    'CONNECTIONS_PER_HOUR' => 'Connections / HOUR',
                    'test' => 'test',
                    'edittable' => 'Database',
                    'rows' => 'Rows',
                    'changecurrentdb' => 'Server',
                    'dragsharelink' => 'dragsharelink',
                    'repair' => 'Repair',
                    'new' => 'New',
                    'street' => 'street',
                    'saveProfile' => 'Profile',
                    'limit' => 'Limit',
                    'profile' => 'profile',
                    'uploads' => 'uploads',
                    'chars' => 'chars',
                    'sort' => 'sort',
                    'createuser' => 'Create User',
                    'LONGTEXT' => '0-4,294,967,295 Chars Attributes: BINARY, CHARACTER SET Default: NULL ["" if NOT NULL]',
                    'EditIndex' => 'Index bearbeiten',
                    'ENUM' => 'Column is exactly 1 of 1-65,535 values Attributes: CHARACTER SET Default: NULL [1st value if NOT NULL]',
                    'admin' => 'admin',
                    'DeleteEntry' => 'Table',
                    'show' => 'Show',
                    'QUERIES_PER_HOUR' => 'QUERIES / HOUR',
                    'newfolder' => 'newfolder',
                    'showcreatetable' => 'New Table',
                    'showprocesslist' => 'Processlist',
                    'navigation' => 'navigation',
                    'readmore' => 'readmore',
                    'phone' => 'phone',
                    'username' => 'username',
                    'repairtable' => 'Repair Table',
                    'newcol' => 'New Column',
                    'DOUBLE' => 'Min=+/-2.225E-308 Max=+/-1.798E+308 Attributes: UNSIGNED, ZEROFILL Default: NULL [0 if NOT NULL]',
                    'lol' => 'lol',
                    'MEDIUMINT' => '-8,388,608 to 8,388,607 [0 to 16,777,215] Attributes:  AUTO_INCREMENT, UNSIGNED, ZEROFILL,SERIAL DEFAULT VALUE Default: NULL [0 if NOT NULL]',
                    'selected' => 'Select all',
                    'showvariables' => 'Variables',
                    '' => '',
                    'failednotindatabase' => 'failed: not in database',
                    'daten' => 'Data',
                    'databases' => 'Databases',
                    'floodtext' => 'floodtext',
                    'pass' => 'pass',
                    'TEXT' => '0-65,535 Chars Attributes: BINARY, CHARACTER SET Default: NULL ["" if NOT NULL]',
                    'headline' => 'headline',
                    'LENGTH' => 'LENGTH',
                    'translate' => 'translate',
                    'newentry' => 'New Entry',
                    'optimizetable' => 'Optimize Table',
                    'servername' => 'servername',
                    'logout' => 'Logout',
                    'wrong_passwort_text' => 'The password must be at least 6 characters in length.',
                    'cookiepath' => 'cookiepath',
                    'codenotcheckedfileerror' => '',
                    'rename' => 'Rename',
                    'table' => 'Table',
                    'editmysqluserrights' => 'Rights',
                    'fields' => 'Fields',
                    'cardinality' => 'cardinality',
                    'properties' => 'properties',
                    'truncate' => 'Truncate',
                    'columns' => 'columns',
                    'style' => 'style',
                    'editmessage' => 'editmessage',
                    'sqleditor' => 'Sql',
                    'realy' => 'realy',
                    'folderfirst' => 'folderfirst',
                    'edit' => 'Edit',
                    'insertafter' => 'After',
                    'newmessagereleased' => 'newmessagereleased',
                    'ShowRights' => 'Rights',
                    'name' => 'Name',
                    'importfirefox' => 'importfirefox',
                    'make' => 'make',
                    'export' => 'Export',
                    'insertname' => 'insertname',
                    'newsperpage' => 'newsperpage',
                    'right_captcha_text' => 'right_captcha_text',
                    'searchHelpTopic' => 'Help',
                    'DropDatabase' => 'Databases',
                    'createnewtable' => 'New Table',
                    'showcreatedatabase' => 'New Database',
                    'index_type' => 'index_type',
                    'Null' => 'Null',
                    'INT' => '-/+2.147E+9 [0 to 4.294E+9] AUTO_INCREMENT, UNSIGNED, ZEROFILL,SERIAL DEFAULT VALUE Default: NULL [0 if NOT NULL]',
                    'TINYTEXT' => '0-255 Characters Attributes: BINARY, CHARACTER SET Default: NULL ["" if NOT NULL]',
                    'BIT' => 'Binary. Display by [add zero or converting with BIN()]. M=1-64 Attributes: Prior to 5.03TINYINT(1) Synonym Default: NULL [0 if NOT NULL]',
                    'addtranslation' => 'addtranslation',
                    'postcode' => 'postcode',
                    'inserttext' => 'inserttext',
                    'mysql' => 'mysql',
                    'changeengine' => 'Change Engine',
                    'LONGBLOB' => '0-4,294,967,295 bytes Attributes: Global Only(case sensitive) Default: NULL ["" if NOT NULL]',
                    'maxuploadsize' => 'maxuploadsize',
                    'DATETIME' => '"1000-01-01 00:00:00" -"9999-12-31 23:59:59" Attributes: Global Only(YYYY-MM-DD hh:mm:ss) Default: NULL ["0000-00-00 00:00:00" if NOT NULL]',
                    'bookmarks' => 'bookmarks',
                    'UPDATES_PER_HOUR' => 'Updates / HOUR',
                    'CHAR' => 'M=0-255 Characters, FIXED.Right padded with spaces. Attributes: BINARY, CHARACTER SET Default: NULL ["" if NOT NULL]'
                  },
          'de' => {
                    'addindex' => 'Index hinzufügen',
                    'news_pro_page' => 'Einträge/Seite',
                    'documentroot' => 'document root',
                    'analyzetable' => 'Analysieren',
                    'droptable' => 'Tabellen',
                    'searchhelptopic' => 'Hilfe',
                    'right_username_text' => 'Ok',
                    'sub_part' => 'sub_part',
                    'uploadsize' => 'uploadsize',
                    'showeditindex' => 'Index erstellen',
                    'choosefile' => 'Datei auswählen',
                    'saveprofile' => 'Profile',
                    'failedinvalidcode' => 'Falscher Code',
                    'retry' => 'Wiederhohlen',
                    'showrights' => 'Rechte',
                    'exportdatabase' => 'Datenbank',
                    'time' => '"-838:59:59" - "838:59:59" Attributes: Global Only(hh:mm:ss) Default: NULL["00:00:00" if NOT NULL]',
                    'edittableprops' => 'Bearbeiten',
                    'select_all' => 'Alle auswählen',
                    'host' => 'Host',
                    'done' => 'fertig',
                    'userprofile' => 'Benutzer Profile',
                    'updates_per_hour' => 'Updates / Stunde',
                    'rowsineffect' => 'betroffene Datensätze',
                    'savetranslate' => 'Übersetzen',
                    'endtable' => 'am ende',
                    'preview' => 'Vorschau',
                    'field' => 'Feld',
                    'enum' => 'Column is exactly 1 of 1-65,535 values Attributes: CHARACTER SET Default: NULL [1st value if NOT NULL]',
                    'size' => 'Größe',
                    'createtable' => 'Tabelle',
                    'right_passwort_text' => 'Ok',
                    'over' => 'über',
                    'drop_database' => 'Datenbank löschen',
                    'addunique' => 'Unique Index hinzufügen',
                    'renametable' => 'Tabelle umbenennen',
                    'char' => 'M=0-255 Characters, FIXED.Right padded with spaces. Attributes: BINARY, CHARACTER SET Default: NULL ["" if NOT NULL]',
                    'showsqlsearch' => 'Suchen',
                    'editentry' => 'Bearbeiten',
                    'reply' => 'Antworten',
                    'homepagetitle' => 'Homepage Titel',
                    'next' => 'Weiter',
                    'shownewrow' => 'Neue Zeile',
                    'int' => '-/+2.147E+9 [0 to 4.294E+9] AUTO_INCREMENT, UNSIGNED, ZEROFILL,SERIAL DEFAULT VALUE Default: NULL [0 if NOT NULL]',
                    'sharelink' => 'sharelink',
                    'uploadchmod' => 'Upload chmod',
                    'permalink' => 'permalink',
                    'activates' => 'Aktiviert',
                    'city' => 'city',
                    'edittranslation' => 'Übersetzen',
                    'maxlength' => 'maximale länge',
                    'explorer' => 'Explorer',
                    'gbook' => 'Gästebuch',
                    'delete' => 'Löschen',
                    'date' => '"1000-01-01" - "9999-12-31" Attributes: Global Only(YYYY-MM-DD) Default: NULL["0000-00-00" if NOT NULL]',
                    'shownewentry' => 'Neuer Eintrag',
                    'regexp' => 'Regulärer Ausdruck',
                    'mediumblob' => '0-16,777,215 bytes Attributes: Global Only(case sensitive) Default: NULL ["" if NOT NULL]',
                    'year' => '1900 - 2155 Attributes: Global Only(YYYY) Default: NULL["0000" if NOT NULL]',
                    'unselect_all' => 'Auswahl aufheben',
                    'showtables' => 'Tabellen',
                    'mediumtext' => '0-16,777,215 Chars Attributes: BINARY, CHARACTER SET Default: NULL ["" if NOT NULL]',
                    'createindex' => 'Index erstellen',
                    'blob' => '0-65,535 bytes Attributes: Global Only(case sensitive) Default: NULL ["" if NOT NULL]',
                    'mediumint' => '-8,388,608 to 8,388,607 [0 to 16,777,215] Attributes:  AUTO_INCREMENT, UNSIGNED, ZEROFILL,SERIAL DEFAULT VALUE Default: NULL [0 if NOT NULL]',
                    'starttable' => 'am Anfang',
                    'login' => 'Anmelden',
                    'column_name' => 'column_name',
                    'rebuild' => 'rebuild',
                    'null' => 'Null',
                    'welcome' => 'Willkommen',
                    'showdatabases' => 'Datenbanken',
                    'trash' => 'Mülleimer',
                    'right_database_name' => 'Ok',
                    'datetime' => '"1000-01-01 00:00:00" -"9999-12-31 23:59:59" Attributes: Global Only(YYYY-MM-DD hh:mm:ss) Default: NULL ["0000-00-00 00:00:00" if NOT NULL]',
                    'queries_per_hour' => 'Anfragen / Stunde',
                    'email' => 'Email Adresse',
                    'details' => 'Details',
                    'timebetweenposts' => 'Zeit zwischen Posts',
                    'sql' => 'SQL',
                    'dropdatabase' => 'Datenbanken',
                    'change' => 'Ändern',
                    'mailsubject' => 'mailsubject',
                    'attribute' => 'Attribute',
                    'showsqleditor' => 'SQL Ausführen',
                    'env' => 'Env-Vars',
                    'changeautoincrementvalue' => 'Auto Increment Wert',
                    'bigint' => '-/+9.223E+18 [0 to 18.45E+18] Attributes: AUTO_INCREMENT, UNSIGNED, ZEROFILL,SERIAL DEFAULT VALUE Default: NULL [0 if NOT NULL]',
                    'processlist' => 'Prozesse',
                    'showtabledetails' => 'Details',
                    'settings' => 'Einstellungen',
                    'save' => 'Speichern',
                    'firstname' => 'Vorname',
                    'regmessage' => 'regmessage',
                    'editnavi' => 'Navigation',
                    'editlinks' => 'Bearbeiten',
                    'defaultaction' => 'default action',
                    'uploadpath' => 'Upload path',
                    'showcreateuser' => 'Benutzer',
                    'wrong_database_name' => 'Falscher Datenbank Name',
                    'collation' => 'Kollation',
                    'catslist' => 'Kategorien',
                    'execsql' => 'Sql ausführen',
                    'createdatabase' => 'Neue Datenbank',
                    'key_name' => 'key_name',
                    'user' => 'Benutzer',
                    'sqlsearch' => 'Suchen',
                    'showusers' => 'Benutzer',
                    'showtable' => 'Tabelle',
                    'seq_in_index' => 'seq_in_index',
                    'rights' => 'Rechte',
                    'after' => 'nach',
                    'search' => 'Suchen',
                    'optimize' => 'Optimieren',
                    'database' => 'Datenbank',
                    'timestamp' => '19700101000000 -2037+ Attributes: Global Only(YYYYMMDDhhmmss) Default: Current Date &amp; Time',
                    'length' => 'länge',
                    'password' => 'Passwort',
                    'showchangecurrentdb' => 'Server',
                    'double' => 'Min=+/-2.225E-308 Max=+/-1.798E+308 Attributes: UNSIGNED, ZEROFILL Default: NULL [0 if NOT NULL]',
                    'links_pro_page' => 'Einträge/Seite',
                    'non_unique' => 'non_unique',
                    'body' => 'Erstelle Deine Nachricht',
                    'user_connections' => 'Maximale Benutzer',
                    'reg' => 'Registrieren',
                    'links' => 'Lesezeichen',
                    'exportoperabookmarks' => 'Opera Lesezeichen exportieren',
                    'downloadfile' => 'Herunterladen',
                    'addprimarykey' => 'Primärschlüssel hinzufügen',
                    'insert' => 'Einfügen',
                    'wrong_username_text' => 'Der Benutzername muss mindestens 3 Zeichen lange sein und darf nur Ziffern und Buchstaben enthalten.',
                    'blog' => 'Notitzen',
                    'newpass' => 'Neues Passwort',
                    'importoperabookmarks' => 'Opera lesezeichen importiere',
                    'register' => 'Registrieren',
                    'connect' => 'Verbinden',
                    'nomail' => 'nomail',
                    'create' => 'Erstellen',
                    'wrong_captcha_text' => 'Capture falsch',
                    't_regtext' => 't_regtext',
                    'answers' => 'Antworten',
                    'showdumptable' => 'Exportieren',
                    'comment' => 'Kommentar',
                    'gbook_body' => 'Erstelle Deine Nachricht.',
                    'back' => 'zurück',
                    'indexover' => 'Index über',
                    'changecharset' => 'Zeichensatz',
                    'varbinary' => '0-65,535 bytesM=0-255 v5.0.3 Attributes: Global Only(case sensitive) Default: NULL ["" if NOT NULL]',
                    'newmessage' => 'Neue Nachricht',
                    'type' => 'Type',
                    'htmlright' => 'Html right',
                    'float' => 'Min=+/-1.175E-38 Max=+/-3.403E+38 Attributes: UNSIGNED, ZEROFILL Default: NULL [0 if NOT NULL]',
                    'deleteentry' => 'Tabelle',
                    'shownewtable' => 'Datenbank',
                    'binary' => 'M=0-255 bytes, FIXED. Attributes: Global Only(case sensitive) Default: NULL ["" if NOT NULL]',
                    'showdumpdatabase' => 'Exportieren',
                    'packed' => 'packed',
                    'test' => 'test',
                    'edittable' => 'Bearbeiten',
                    'rows' => 'Zeilen',
                    'tinyblob' => '0-255 bytes Attributes: Global Only(case sensitive) Default: NULL ["" if NOT NULL]',
                    'dragsharelink' => 'dragsharelink',
                    'changecurrentdb' => 'Server',
                    'longtext' => '0-4,294,967,295 Chars Attributes: BINARY, CHARACTER SET Default: NULL ["" if NOT NULL]',
                    'repair' => 'Reparieren',
                    'new' => 'Neu',
                    'street' => 'Straße',
                    'limit' => 'Limit',
                    'showprofile' => 'Profile',
                    'dropcolumn' => 'Spalte löschen',
                    'speichern' => 'Speichern',
                    'uploads' => 'Uploads',
                    'profile' => 'Profile',
                    'sort' => 'Sortieren',
                    'createuser' => 'Neuer Benutzer',
                    'chars' => 'Zeichen',
                    'connections_per_hour' => 'Verbindungen / Stunde',
                    'admin' => 'Admin',
                    'saverights' => 'Rechte',
                    'saveedittable' => 'Speichern',
                    'show' => 'Anzeigen',
                    'addfulltext' => 'Add Fulltext',
                    'showcreatetable' => 'Tabelle erstellen',
                    'newfolder' => 'Neues Verzeichnis',
                    'showprocesslist' => 'Processe',
                    'navigation' => 'Navigation',
                    'readmore' => 'mehr',
                    'text' => '0-65,535 Chars Attributes: BINARY, CHARACTER SET Default: NULL ["" if NOT NULL]',
                    'phone' => 'Telefon',
                    'username' => 'Name',
                    'repairtable' => 'Reparieren',
                    'newcol' => 'Neue Zeile',
                    'lol' => 'lol',
                    'bit' => 'Binary. Display by [add zero or converting with BIN()]. M=1-64 Attributes: Prior to 5.03TINYINT(1) Synonym Default: NULL [0 if NOT NULL]',
                    'showvariables' => 'Variablen',
                    'selected' => 'Alle auswählen',
                    'default' => 'Default',
                    'failednotindatabase' => 'Nicht in Datenbank',
                    'daten' => 'Daten',
                    'databases' => 'Datenbanken',
                    'floodtext' => 'nicht so oft posten',
                    'pass' => 'Passwort',
                    'translate' => 'Übersetzen',
                    'headline' => 'Überschrift',
                    'newentry' => 'Neuer Eintrag',
                    'servername' => 'Server-Name',
                    'optimizetable' => 'Optimieren',
                    'logout' => 'Abmelden',
                    'wrong_passwort_text' => 'Das Passwort muss mindestens 6 zeichen lang sein',
                    'cookiepath' => 'cookiepath',
                    'codenotcheckedfileerror' => '',
                    'rename' => 'Umbenennen',
                    'longblob' => '0-4,294,967,295 bytes Attributes: Global Only(case sensitive) Default: NULL ["" if NOT NULL]',
                    'set' => '("A1","A2",...) Column is 0 or more values in list of 1-64 members Attributes: CHARACTER SET Default: NULL ["" if NOT NULL]',
                    'varchar' => 'M=0-65,535 CharactersM=0-255 v5.0.3 Attributes: BINARY, CHARACTER SET Default: NULL ["" if NOT NULL]',
                    'table' => 'Tabelle erstellen',
                    'editmysqluserrights' => 'Benutzerrechte',
                    'smallint' => '-32,768 to 32,767 [0 to 65,535] Attributes: AUTO_INCREMENT, UNSIGNED, ZEROFILL,SERIAL DEFAULT VALUE Default: NULL [0 if NOT NULL]',
                    'properties' => 'Einstellungen',
                    'fields' => 'Spalten',
                    'cardinality' => 'cardinality',
                    'truncate' => 'Leeren',
                    'editindex' => 'Index bearbeiten',
                    'checkformsddfsds' => 'true',
                    'style' => 'Style',
                    'lang' => 'de',
                    'columns' => 'columns',
                    'sqleditor' => 'Sql',
                    'editmessage' => 'Bearbeiten',
                    'realy' => 'wirklich',
                    'tinytext' => '0-255 Characters Attributes: BINARY, CHARACTER SET Default: NULL ["" if NOT NULL]',
                    'folderfirst' => 'Verzeichnisse zuerst anzeigen.',
                    'edit' => 'Bearbeiten',
                    'decimal' => 'Stored as string Max Range = DOUBLE rangeFixed point vs. DOUBLE float Attributes: UNSIGNED, ZEROFILL Default: NULL [0 if NOT NULL]',
                    'insertafter' => 'Einfügen',
                    'newmessagereleased' => 'Nachricht erstellt',
                    'name' => 'Name',
                    'make' => 'erstellen',
                    'importfirefox' => 'Firefox lesezeichen importieren',
                    'export' => 'Exportieren',
                    'extra' => 'Extra',
                    'insertname' => 'Name angeben',
                    'newsperpage' => 'Einträge/Seite',
                    'tinyint' => 'TINYINT -128 TO 127  [0 to 255 if UNSIGNED],Attributes: AUTO_INCREMENT  UNSIGNED, ZEROFILL,SERIAL DEFAULT VALUE Default: NULL [0 if NOT NULL]',
                    'right_captcha_text' => 'Ok',
                    'createnewtable' => 'Neue Tabelle',
                    'showcreatedatabase' => 'Datenbank',
                    'index_type' => 'index_type',
                    'postcode' => 'Postleitzahl',
                    'addtranslation' => 'Neue Übersetzung',
                    'mysql' => 'mysql',
                    'inserttext' => 'Text einfügen',
                    'changeengine' => 'Engine',
                    'maxuploadsize' => 'maxuploadsize',
                    'bookmarks' => 'Lesezeichen'
                  }
        };
$lang =$VAR1;