$VAR1 = [
          {
            'id' => 'a1',
            'text' => 'Sourceforge',
            'rid' => 1,
            'subtree' => [
                           {
                             'id' => 'a2',
                             'href' => 'http://lindnerei.sourceforge.net/',
                             'target' => '_blank',
                             'rid' => 2,
                             'text' => 'MySQL::Admin',
                             'subtree' => []
                           },
                           {
                             'id' => 'a3',
                             'href' => 'https://sourceforge.net/p/lindnerei/ajax/HEAD/tree/',
                             'rid' => 3,
                             'text' => 'Subversion',
                             'subtree' => []
                           }
                         ]
          },
          {
            'id' => 'a4',
            'href' => 'https://metacpan.org/pod/MySQL::Admin',
            'rid' => 4,
            'text' => 'Metacpan',
            'subtree' => []
          },
          {
            'id' => 'a5',
            'href' => 'http://search.cpan.org/~lze/MySQL-Admin-0.62/lib/MySQL/Admin.pm',
            'text' => 'Cpan',
            'rid' => 5,
            'subtree' => []
          },
          {
            'id' => 'a6',
            'href' => 'http://lindnerei.sourceforge.net/main.html',
            'text' => 'Dirk Lindner',
            'rid' => 6,
            'subtree' => []
          },
          {
            'tabindex' => '',
            'href' => 'http://www.perlmonks.org/?node_id=1135188',
            'rev' => '',
            'onmousemove' => '',
            'rid' => 7,
            'subtree' => [],
            'rel' => '',
            'onmouseup' => '',
            'id' => 'a7',
            'onmousedown' => '',
            'accesskey' => '',
            'shape' => '',
            'type' => '',
            'dir' => '',
            'target' => '_blank',
            'onmouseout' => '',
            'onfocus' => '',
            'lang' => '',
            'ondblclick' => '',
            'style' => '',
            'onkeydown' => '',
            'onmouseover' => '',
            'title' => '',
            'hreflang' => '',
            'name' => '',
            'charset' => '',
            'onblur' => '',
            'onclick' => '',
            'coords' => '',
            'onkeypress' => '',
            'right' => '',
            'text' => 'Perlmonks',
            'onkeyup' => ''
          }
        ];
@TreeView = $VAR1;