[previewHeadline]
<div id="ptitel" ><b></b></div>
[/previewHeadline]
[previewBody]
<a name="name" id="headline2" ></a><div id="pbody" ></div>
<br/><br/>
[/previewBody]
[editor]
<div align="center"><form name="postmodify" action="" method="get"  enctype="multipart/form-data" onsubmit="submitForm(this,'[action/]','[action/]');return false;">
<table align="center" border="0" cellpadding="0" cellspacing="0" summary="editor" width="100%" >
<tr>
<td>
<table align="center" border="0" cellpadding="1" cellspacing="1" width="100%">
<tr>
<td colspan="2" align="left">[buttons/]</td>
</tr>
<tr>
<td width="*"><a name="winedit"></a><input name="headline" id="title" maxlength="50" value="[headline/]"  align="left" size="50" type="text" style="width:100%;"/>
</td><td align="right">[catlist/][atemp/]</td>
</tr>
<tr>
<td align="center" colspan="2"><textarea rows="10" cols="50" class="editForm" name="message" id="txt" onclick="checkLength()" onkeypress="checkLength()" onkeyup="checkLength()" style="width:95%;height:600px" onkeydown="checkLength()" onchange="checkLength()">[body/]</textarea>
 <script language="JavaScript1.5" type="text/javascript">
 blogThis();</script>
</td>
</tr>
<tr><td colspan="2">
<table align="center" border="0" cellpadding="0" cellspacing="0" summary="chars-left" >
<tr>
<td>[tr=chars/]</td><td><input value="[maxlength/]" id="msglength" style="width:50px;color:green;background-color:#E6DADE;" disabled="disabled"/></td>
</tr>
</table>
<input  name="action" value="[action/]" type="hidden"/>
<input  name="thread" value="[thread/]" type="hidden"/>
<input  name="reply" value="[reply/]" type="hidden"/>
</td>
</tr>
<tr>
<td align="left" colspan="2">
[attach/]
</td>
</tr>
<tr>
<td align="right" colspan="2">
  <input type="submit" name="submit" onclick="act ='[tr=preview/]';" align="middle" alt="preview" value="[tr=preview/]" title="[tr=preview/]"/>&#160;
  <input type="submit" name="submit" style="cursor:pointer;" align="middle" value="[tr=save/]" title="[tr=save/]" onclick="act ='[tr=save/]';return confirm('[tr=realy/] [tr=save/] ?');" />
</td>
</tr>
</table>
</td>
</tr>
</table>
</form></div>
[/editor]
