$VAR1 = [
          {
            'tabindex' => '',
            'rev' => '',
            'href' => '',
            'onmousemove' => '',
            'rid' => 1,
            'subtree' => [],
            'rel' => '',
            'onmouseup' => '',
            'id' => 'a1',
            'accesskey' => '',
            'onmousedown' => '',
            'shape' => '',
            'type' => '',
            'dir' => '',
            'target' => '',
            'onmouseout' => '',
            'onfocus' => '',
            'style' => '',
            'lang' => '',
            'ondblclick' => '',
            'onkeydown' => '',
            'title' => '',
            'onmouseover' => '',
            'hreflang' => '',
            'name' => '',
            'charset' => '',
            'onblur' => '',
            'onclick' => 'requestURI(\'/cgi-bin/mysql.pl?action=EditFile&name=\'+cAction,\'EditFile\',\'EditFile\');',
            'coords' => '',
            'onkeypress' => '',
            'right' => '5',
            'text' => 'Edit File',
            'onkeyup' => ''
          }
        ];
@TreeView = $VAR1;