$VAR1 = {
          'admin' => {
                       'password' => 'testpass'
                     },
          'config' => '/var/www/cgi-bin/config/settings.pl',
          'mod' => 1,
          'actions' => '/var/www/cgi-bin/config/actions.pl',
          'version' => '0.89',
          'cgi' => {
                     'DocumentRoot' => '/var/www/htdocs',
                     'title' => 'MySQL::Admin',
                     'alias' => 'perl',
                     'bin' => '/var/www/cgi-bin',
                     'cookiePath' => '/',
                     'expires' => '+1y',
                     'style' => 'mysql',
                     'serverName' => 'localhost'
                   },
          'session' => '/var/www/cgi-bin/config/session.pl',
          'scriptAlias' => 'perl',
          'database' => {
                          'CurrentPass' => 'keinz',
                          'CurrentHost' => 'localhost',
                          'host' => 'localhost',
                          'name' => 'LZE',
                          'CurrentUser' => 'root',
                          'CurrentDb' => 'LZE',
                          'user' => 'root',
                          'password' => 'keinz'
                        },
          'floodtime' => 10,
          'files' => {
                       'owner' => 'lze',
                       'group' => 'lze',
                       'chmod' => '0755'
                     },
          'apacheconfig' => '/etc/apache2/sites-enabled/',
          'translate' => '/var/www/cgi-bin/config/translate.pl',
          'uploads' => {
                         'chmod' => 438,
                         'maxlength' => 21000000,
                         'path' => '/var/www/htdocs/download'
                       },
          'language' => 'en'
        };
$m_hrSettings =$VAR1;